# django-admin-honeypot

django-admin-honeypot is fake Django admin login page that logs all attempts to login in the database. The purpose is to give administrators some insight into who is attempting to gain unauthorized access to their Django-powered website.

* **Author**: [Derek Payton](http://dmpayton.com)
* **Version**: 0.1.0
* **License**: MIT

## Usage

* Add `admin_honeypot` to `INSTALLED_APPS`.
* Update your urls.py:

    ```
    urlpatterns = patterns(''
        ...
        url(r'^admin/', include('admin_honeypot.urls')),
        url(r'^secret/', include(admin.site.urls)),
    )
    ```

## Signals

`admin_honeypot.signals.honeypot` is called on every login attempt with the following arguments:

* **instance**: The LoginAttempt object created
* **request**: The current request object

## Testing

    python manage.py test admin_honeypot

Currently there is a single test that submits the fake login form and checks that the data was saved to the database.
